@@ -11,7 +11,7 @@ import warnings
 from abc import ABCMeta
 from copy import deepcopy
 from enum import Enum
-from functools import lru_cache, wraps
+from functools import wraps
 from pathlib import Path
 from textwrap import wrap
 from typing import List, Union, Dict
@@ -23,6 +23,7 @@ import numpy as np
 import xarray as xr
 from IPython.display import display
 from matplotlib.collections import QuadMesh
+from methodtools import lru_cache
 from qcodes.utils.helpers import NumpyJSONEncoder
 from uncertainties import ufloat
 
@@ -44,6 +45,8 @@ from quantify_core.visualization.SI_utilities import adjust_axeslabels_SI, set_c
 
 from .types import AnalysisSettings
 
+FIGURES_LRU_CACHE_SIZE = 8
+
 
 @dataclass
 class _FiguresMplCache:
@@ -53,11 +56,6 @@ class _FiguresMplCache:
     initialized: bool
 
 
-@lru_cache(maxsize=8)
-def _analyses_figures_cache(_: BaseAnalysis):
-    return _FiguresMplCache({}, {}, False)
-
-
 # global configurations at the level of the analysis module
 settings = AnalysisSettings(
     {
@@ -141,13 +139,13 @@ class AnalysisMeta(ABCMeta):
 
             @wraps(create_figures_orig)
             def create_figures_patched(self):
-                _analyses_figures_cache(self).initialized = True
+                self._analyses_figures_cache().initialized = True
                 self._creating_figures = True
                 create_figures_orig(self)
                 self._creating_figures = False
 
             def _figs_axs_mpl(self):
-                cache = _analyses_figures_cache(self)
+                cache = self._analyses_figures_cache()
                 if not cache.initialized and not self._creating_figures:
                     create_figures_patched(self)
                 return cache
@@ -179,6 +177,7 @@ class BaseAnalysis(metaclass=AnalysisMeta):
         tuid: Union[TUID, str] = None,
         label: str = "",
         settings_overwrite: dict = None,
+        plot_figures: bool = True,
     ):
         """
         Initializes the variables used in the analysis and to which data is stored.
@@ -208,6 +207,8 @@ class BaseAnalysis(metaclass=AnalysisMeta):
             A dictionary containing overrides for the global
             `base_analysis.settings` for this specific instance.
             See `Settings schema` above for available settings.
+        plot_figures:
+            Option to create and save figures for analysis.
         """
         # NB at least logging.basicConfig() needs to be called in the python kernel
         # in order to see the logger messages
@@ -238,6 +239,8 @@ class BaseAnalysis(metaclass=AnalysisMeta):
 
         self.fit_results = {}
 
+        self.plot_figures = plot_figures
+
     analysis_steps = AnalysisSteps
     """
     Defines the steps of the analysis specified as an :class:`~enum.Enum`.
@@ -347,6 +350,10 @@ class BaseAnalysis(metaclass=AnalysisMeta):
 
         return results_dir
 
+    @lru_cache(maxsize=FIGURES_LRU_CACHE_SIZE)
+    def _analyses_figures_cache(self):
+        return _FiguresMplCache({}, {}, False)
+
     @property
     def results_dir(self):
         """
@@ -410,11 +417,20 @@ class BaseAnalysis(metaclass=AnalysisMeta):
                 )
                 return
 
+    # pylint: disable=no-member
     def get_flow(self) -> tuple:
         """
         Returns a tuple with the ordered methods to be called by run analysis.
+        Only return the figures methods if :code:`self.plot_figures` is :code:`True`.
         """
-        return tuple(getattr(self, elm.value) for elm in self.analysis_steps)
+        if self.plot_figures:
+            return tuple(getattr(self, elm.value) for elm in self.analysis_steps)
+
+        return tuple(
+            getattr(self, elm.value)
+            for elm in self.analysis_steps
+            if "figures" not in elm.value
+        )
 
     def extract_data(self):
         """
@@ -726,7 +742,7 @@ class Basic1DAnalysis(BasicAnalysis):
     """
 
     def run(self) -> BaseAnalysis:
-        warnings.warn("Use `BasicAnalysis`", category=DeprecationWarning)
+        warnings.warn("Use `BasicAnalysis`", category=FutureWarning)
         return super().run()
 
 
