@@ -46,7 +46,7 @@ class OptimizationAnalysis(ba.BaseAnalysis):
 
         arg_optimum_function = np.argmin if self.minimize else np.argmax
         optimum_function = np.min if self.minimize else np.max
-        optimum_text = "mimimum" if self.minimize else "maximum"
+        optimum_text = "minimum" if self.minimize else "maximum"
 
         # Go through every y variable and find the optimal point
         y_variable = "y0"
@@ -115,8 +115,8 @@ def iteration_plots(dataset, quantities_of_interest):
         ax.plot(values, marker=".", linewidth="0.5", markersize="4.5")
         adjust_axeslabels_SI(ax)
 
-        qpl.set_ylabel(ax, variable_name, dataset[variable].units)
-        qpl.set_xlabel(ax, "iteration index")
+        qpl.set_ylabel(variable_name, dataset[variable].units, axis=ax)
+        qpl.set_xlabel("iteration index", axis=ax)
 
         qpl.set_suptitle_from_dataset(
             fig, dataset, f"{variable_name} vs iteration number:"
