@@ -2,11 +2,12 @@
 # Licensed according to the LICENCE file on the main branch
 """Helpers for performing experiments."""
 import warnings
-from typing import Any, Optional, Union, Dict
+from typing import Any, Optional, Union, Dict, List
 
 import numpy as np
 
-from qcodes.instrument import Instrument, InstrumentChannel
+from qcodes.instrument import Instrument, Parameter
+from qcodes.instrument.channel import InstrumentChannel
 
 from quantify_core.data.handling import get_latest_tuid, load_snapshot
 from quantify_core.data.types import TUID
@@ -15,18 +16,22 @@ from quantify_core.visualization.pyqt_plotmon import PlotMonitor_pyqt
 
 
 def load_settings_onto_instrument(
-    instrument: Instrument, tuid: TUID = None, datadir: str = None
+    instrument: Union[Instrument, InstrumentChannel, Parameter],
+    tuid: TUID = None,
+    datadir: str = None,
 ) -> None:
     """
     Loads settings from a previous experiment onto a current
-    :class:`~qcodes.instrument.Instrument`. This information
-    is loaded from the 'snapshot.json' file in the provided experiment
-    directory.
+    :class:`~qcodes.instrument.Instrument`, or any of its submodules or
+    parameters. This information is loaded from the 'snapshot.json' file in
+    the provided experiment directory.
 
     Parameters
     ----------
-    instrument : :class:`~qcodes.instrument.Instrument`
-        the instrument to be configured.
+    instrument :
+        the :class:`~qcodes.instrument.Instrument`,
+        :class:`~qcodes.instrument.InstrumentChannel` or
+        :class:`~qcodes.instrument.Parameter` to be configured.
     tuid : :class:`~quantify_core.data.types.TUID`
         the TUID of the experiment. If None use latest TUID.
     datadir : str
@@ -44,15 +49,6 @@ def load_settings_onto_instrument(
     instruments_numpy_array = load_snapshot(tuid, datadir, list_to_ndarray=True)[
         "instruments"
     ]
-    if instrument.name not in instruments:
-        raise ValueError(
-            'Instrument "{}" not found in snapshot {}:{}'.format(
-                instrument.name, datadir, tuid
-            )
-        )
-
-    instr_snap = instruments[instrument.name]
-    instr_snap_numpy_array = instruments_numpy_array[instrument.name]
 
     def _try_to_set_par_safe(
         instr_mod: Union[Instrument, InstrumentChannel],
@@ -76,6 +72,41 @@ def load_settings_onto_instrument(
                 f'could not be set to "{value}" due to error:\n{exc}'
             )
 
+    parents = get_all_parents(instrument)
+
+    # Find the snapshot for this instrument, submodule or parameter
+    for parent in parents:
+        if isinstance(parent, Instrument):
+            if parent.name not in instruments:
+                raise ValueError(
+                    f'Instrument "{parent.name}" not found in snapshot {datadir}:{tuid}'
+                )
+            instr_mod_snap = instruments[parent.name]
+            instr_mod_snap_numpy_array = instruments_numpy_array[parent.name]
+
+        if isinstance(parent, InstrumentChannel):
+            if parent._short_name not in instr_mod_snap["submodules"]:
+                raise ValueError(
+                    f'Submodule "{parent.name}" not found in snapshot {datadir}:{tuid}'
+                )
+            instr_mod_snap = instr_mod_snap["submodules"][parent._short_name]
+            instr_mod_snap_numpy_array = instr_mod_snap_numpy_array["submodules"][
+                parent._short_name
+            ]
+
+        # If we are only setting one parameter, try to set this immediately
+        if isinstance(parent, Parameter):
+            if parent.name not in instr_mod_snap["parameters"]:
+                address = ".".join([p._short_name for p in parents])
+                raise ValueError(
+                    f'Parameter "{address}" not found in snapshot {datadir}:{tuid}'
+                )
+            value = instr_mod_snap["parameters"][parent.name]["value"]
+            if isinstance(parent(), np.ndarray):
+                value = instr_mod_snap_numpy_array["parameters"][parent.name]["value"]
+            _try_to_set_par_safe(parents[-2], parent.name, value)
+            return
+
     def _set_params_instr_mod(
         instr_mod_snap: Dict,
         instr_mod_snap_np: Dict,
@@ -110,12 +141,38 @@ def load_settings_onto_instrument(
 
     # set the top-level parameters and then recursively set parameters of submodules
     _set_params_instr_mod(
-        instr_mod_snap=instr_snap,
-        instr_mod_snap_np=instr_snap_numpy_array,
+        instr_mod_snap=instr_mod_snap,
+        instr_mod_snap_np=instr_mod_snap_numpy_array,
         instr_mod=instrument,
     )
 
 
+def get_all_parents(instr_mod: Union[Instrument, InstrumentChannel, Parameter]) -> List:
+    """
+    Get a list of all the parent submodules and instruments of a given QCodes
+    instrument, submodule or parameter.
+
+    Parameters
+    -----------
+    instr_mod:
+        The QCodes instrument, submodule or parameter whose parents we wish to find
+
+    Returns
+    -----------
+    A list of all the parents of that object (and the object itself)
+    """
+    if hasattr(instr_mod, "_parent"):
+        parents = get_all_parents(instr_mod._parent)
+        parents.append(instr_mod)
+    elif hasattr(instr_mod, "_instrument"):
+        parents = get_all_parents(instr_mod._instrument)
+        parents.append(instr_mod)
+    else:
+        parents = [instr_mod]
+
+    return parents
+
+
 def create_plotmon_from_historical(
     tuid: Optional[TUID] = None, label: str = ""
 ) -> PlotMonitor_pyqt:
@@ -141,14 +198,15 @@ def create_plotmon_from_historical(
         the plotmon
     """
     # avoid creating a plotmon with the same name
-    name = tuid = tuid or get_latest_tuid(contains=label)
-    name_str = str(name)
-    i = 0
+    if tuid is None:
+        tuid = get_latest_tuid(contains=label)
 
-    for plotmon_class in get_subclasses(PlotMonitor_pyqt, include_base=True):
-        for plotmon in plotmon_class.instances():
-            if name_str == plotmon.name:
-                name_str += f"_{i}"
+    tuid_str = str(tuid)
+    # python attributes can't start with a number
+    name = "_" + tuid_str
+
+    # hyphens not allowed in instrument names for qcodes v0.34 and up
+    name = name.replace("-", "_")
 
     plotmon = PlotMonitor_pyqt(name)
     plotmon.tuids_append(tuid)
