@@ -1,11 +1,11 @@
 # Repository: https://gitlab.com/quantify-os/quantify-core
-# Licensed according to the LICENCE file on the master branch
+# Licensed according to the LICENCE file on the main branch
 """Plot interpolations."""
 import logging
+from typing import Literal
 
 import numpy as np
 from scipy import interpolate
-from typing_extensions import Literal
 
 
 def areas(ip):
