@@ -29,6 +29,17 @@ def t1_analysis_no_cal_points(tmp_test_data_dir):
     return T1Analysis(tuid=tuid).run()
 
 
+def test_t1_load_fit_results(t1_analysis_no_cal_points, tmp_test_data_dir):
+    set_datadir(tmp_test_data_dir)
+    for fit_name, fit_result in t1_analysis_no_cal_points.fit_results.items():
+
+        loaded_fit_result = T1Analysis.load_fit_result(
+            tuid=t1_analysis_no_cal_points.tuid, fit_name=fit_name
+        )
+
+        assert loaded_fit_result.params == fit_result.params
+
+
 def test_t1_figures_generated(t1_analysis_no_cal_points):
     """
     Test that the right figures get created.
@@ -108,6 +119,15 @@ def test_echo_analysis_no_cal(tmp_test_data_dir):
     # accurate to < 1 %
     assert meas_echo == approx(exp_t2_echo, rel=0.01)
 
+    # Test loading and saving fit result object
+    for fit_name, fit_result in analysis_obj.fit_results.items():
+
+        loaded_fit_result = EchoAnalysis.load_fit_result(
+            tuid=analysis_obj.tuid, fit_name=fit_name
+        )
+
+        assert loaded_fit_result.params == fit_result.params
+
 
 def test_echo_analysis_with_cal(tmp_test_data_dir):
     set_datadir(tmp_test_data_dir)
@@ -191,6 +211,17 @@ def ramsey_analysis_qubit_freq(tmp_test_data_dir):
     return analysis
 
 
+def test_ramsey_load_fit_results(ramsey_analysis_qubit_freq, tmp_test_data_dir):
+    set_datadir(tmp_test_data_dir)
+    for fit_name, fit_result in ramsey_analysis_qubit_freq.fit_results.items():
+
+        loaded_fit_result = RamseyAnalysis.load_fit_result(
+            tuid=ramsey_analysis_qubit_freq.tuid, fit_name=fit_name
+        )
+
+        assert loaded_fit_result.params == fit_result.params
+
+
 def test_figures_generated_qubit_freq_qubit_freq(ramsey_analysis_qubit_freq):
     """test that the right figures get created"""
     assert set(ramsey_analysis_qubit_freq.figs_mpl.keys()) == {
@@ -344,16 +375,35 @@ def test_allxy_dataset_processed(allxy_analysis_obj):
 
 # Test that the analysis returns an error when the number of datapoints
 # is not a multiple of 21
-def test_allxy_analysis_invalid_data(tmp_test_data_dir):
+def test_allxy_analysis_invalid_data(caplog, tmp_test_data_dir):
     set_datadir(tmp_test_data_dir)
+    analysis = AllXYAnalysis(tuid="20210422-104958-297-7d6034").run()
+    assert isinstance(analysis, AllXYAnalysis)
+
+    assert len(caplog.records) == 1
+    record = caplog.records[0]
+    assert (
+        'Exception was raised while executing analysis step 1 ("<bound method '
+        "AllXYAnalysis.process_data of "
+        "<quantify_core.analysis.single_qubit_timedomain.AllXYAnalysis object at"
+        in record.msg
+    )
+    exception = record.exc_info[1]
+    assert isinstance(exception, ValueError)
+    assert exception.args[0].startswith(
+        "Invalid dataset. The number of calibration points"
+    )
+
+
+def test_allxy_load_fit_results_missing(tmp_test_data_dir):
+    set_datadir(tmp_test_data_dir)
+
     with pytest.raises(
-        ValueError,
-        match=(
-            "Invalid dataset. The number of calibration points in an "
-            "AllXY experiment must be a multiple of 21"
-        ),
+        FileNotFoundError, match="No fit results found for this analysis."
     ):
-        AllXYAnalysis(tuid="20210422-104958-297-7d6034").run()
+        AllXYAnalysis.load_fit_result(
+            tuid="20210419-173649-456-23c5f3", fit_name="fit_name"
+        )
 
 
 @pytest.fixture(scope="session", autouse=True)
@@ -363,6 +413,17 @@ def rabi_analysis_obj(tmp_test_data_dir):
     return rabi_analysis_obj
 
 
+def test_rabi_load_fit_results(rabi_analysis_obj, tmp_test_data_dir):
+    set_datadir(tmp_test_data_dir)
+    for fit_name, fit_result in rabi_analysis_obj.fit_results.items():
+
+        loaded_fit_result = RabiAnalysis.load_fit_result(
+            tuid=rabi_analysis_obj.tuid, fit_name=fit_name
+        )
+
+        assert loaded_fit_result.params == fit_result.params
+
+
 def test_figures_generated(rabi_analysis_obj):
     """test that the right figures get created"""
     assert set(rabi_analysis_obj.figs_mpl.keys()) == {
